==> jc-1.4.0.tar.gz: javax/net/VanillaServerSocketFactory.h <==
// class javax.net.VanillaServerSocketFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 832a3372b5f2d586 javax_net_ServerSocketFactory
// @dep_class b961533bf4978c8e javax_net_VanillaServerSocketFactory

// header file dependencies
// @dep_header javax_net_ServerSocketFactory

#include "javax/net/ServerSocketFactory.h"

#ifndef _JC_javax_net_VanillaServerSocketFactory_H_
#define _JC_javax_net_VanillaServerSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_ServerSocket$object;

// Typedefs
typedef struct _jc_javax_net_VanillaServerSocketFactory$sub_refs	_jc_javax_net_VanillaServerSocketFactory$sub_refs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs	_jc_javax_net_VanillaServerSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$refs	_jc_javax_net_VanillaServerSocketFactory$refs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$nonrefs	_jc_javax_net_VanillaServerSocketFactory$nonrefs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$object	_jc_javax_net_VanillaServerSocketFactory$object;

typedef const struct _jc_javax_net_VanillaServerSocketFactory$vmethods	_jc_javax_net_VanillaServerSocketFactory$vmethods;
typedef const struct _jc_javax_net_VanillaServerSocketFactory$vtable	_jc_javax_net_VanillaServerSocketFactory$vtable;
typedef const struct _jc_javax_net_VanillaServerSocketFactory$vtype	_jc_javax_net_VanillaServerSocketFactory$vtype;

// Constructors
extern void _jc_javax_net_VanillaServerSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *);

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$490aca1a1787c4b2(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *);
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint);
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$ef70c1e044cb68fe(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint);
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$ad748fef2e153bff(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint, struct _jc_java_net_InetAddress$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$490aca1a1787c4b2;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$ef70c1e044cb68fe;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$ad748fef2e153bff;

// Virtual methods structure
struct _jc_javax_net_VanillaServerSocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$490aca1a1787c4b2)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *);
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint);
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$ef70c1e044cb68fe)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint);
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$ad748fef2e153bff)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint, struct _jc_java_net_InetAddress$object *);
};

// Vtable
struct _jc_javax_net_VanillaServerSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ServerSocketFactory$vmethods	javax_net_ServerSocketFactory;
	_jc_javax_net_VanillaServerSocketFactory$vmethods	javax_net_VanillaServerSocketFactory;
};

// Vtype
struct _jc_javax_net_VanillaServerSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_VanillaServerSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_VanillaServerSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_VanillaServerSocketFactory$refs {
    _jc_javax_net_VanillaServerSocketFactory$sub_refs	javax_net_VanillaServerSocketFactory;
    _jc_javax_net_ServerSocketFactory$sub_refs	javax_net_ServerSocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_VanillaServerSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ServerSocketFactory$sub_nonrefs	javax_net_ServerSocketFactory;
    _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs	javax_net_VanillaServerSocketFactory;
};

// Object instance structure
struct _jc_javax_net_VanillaServerSocketFactory$object {
	_jc_javax_net_VanillaServerSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_VanillaServerSocketFactory$vtype	*vtype;
	_jc_javax_net_VanillaServerSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_VanillaServerSocketFactory$vtype _jc_javax_net_VanillaServerSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_VanillaServerSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_VanillaServerSocketFactory$class_object;

#endif	/* _JC_javax_net_VanillaServerSocketFactory_H_ */

==> jc-1.4.6.tar.gz: javax/net/VanillaServerSocketFactory.h <==
// class javax.net.VanillaServerSocketFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 832a3372b5f2d586 javax_net_ServerSocketFactory
// @dep_class b961533bf4978c8e javax_net_VanillaServerSocketFactory

// header file dependencies
// @dep_header javax_net_ServerSocketFactory

#include "javax/net/ServerSocketFactory.h"

#ifndef _JC_javax_net_VanillaServerSocketFactory_H_
#define _JC_javax_net_VanillaServerSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_ServerSocket$object;

// Typedefs
typedef struct _jc_javax_net_VanillaServerSocketFactory$sub_refs	_jc_javax_net_VanillaServerSocketFactory$sub_refs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs	_jc_javax_net_VanillaServerSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$refs	_jc_javax_net_VanillaServerSocketFactory$refs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$nonrefs	_jc_javax_net_VanillaServerSocketFactory$nonrefs;
typedef struct _jc_javax_net_VanillaServerSocketFactory$object	_jc_javax_net_VanillaServerSocketFactory$object;

typedef const struct _jc_javax_net_VanillaServerSocketFactory$vmethods	_jc_javax_net_VanillaServerSocketFactory$vmethods;
typedef const struct _jc_javax_net_VanillaServerSocketFactory$vtable	_jc_javax_net_VanillaServerSocketFactory$vtable;
typedef const struct _jc_javax_net_VanillaServerSocketFactory$vtype	_jc_javax_net_VanillaServerSocketFactory$vtype;

// Constructors
extern void _jc_javax_net_VanillaServerSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$490aca1a1787c4b2(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$ef70c1e044cb68fe(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_ServerSocket$object *_jc_javax_net_VanillaServerSocketFactory$method$createServerSocket$ad748fef2e153bff(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint, struct _jc_java_net_InetAddress$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$490aca1a1787c4b2;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$ef70c1e044cb68fe;
extern _jc_method _jc_javax_net_VanillaServerSocketFactory$method_info$createServerSocket$ad748fef2e153bff;

// Virtual methods structure
struct _jc_javax_net_VanillaServerSocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$490aca1a1787c4b2)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$ef70c1e044cb68fe)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$ad748fef2e153bff)(_jc_env *, struct _jc_javax_net_VanillaServerSocketFactory$object *, jint, jint, struct _jc_java_net_InetAddress$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_VanillaServerSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ServerSocketFactory$vmethods	javax_net_ServerSocketFactory;
	_jc_javax_net_VanillaServerSocketFactory$vmethods	javax_net_VanillaServerSocketFactory;
};

// Vtype
struct _jc_javax_net_VanillaServerSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_VanillaServerSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_VanillaServerSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_VanillaServerSocketFactory$refs {
    _jc_javax_net_VanillaServerSocketFactory$sub_refs	javax_net_VanillaServerSocketFactory;
    _jc_javax_net_ServerSocketFactory$sub_refs	javax_net_ServerSocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_VanillaServerSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ServerSocketFactory$sub_nonrefs	javax_net_ServerSocketFactory;
    _jc_javax_net_VanillaServerSocketFactory$sub_nonrefs	javax_net_VanillaServerSocketFactory;
};

// Object instance structure
struct _jc_javax_net_VanillaServerSocketFactory$object {
	_jc_javax_net_VanillaServerSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_VanillaServerSocketFactory$vtype	*vtype;
	_jc_javax_net_VanillaServerSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_VanillaServerSocketFactory$vtype _jc_javax_net_VanillaServerSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_VanillaServerSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_VanillaServerSocketFactory$class_object;

#endif	/* _JC_javax_net_VanillaServerSocketFactory_H_ */
